import tensorflow as tf 
from rokon.RNet import RNet1, RNet2 
 
model_dict = { 
    "RNet1": RNet1, 
    "RNet2": RNet2, 
} 
 
def get_rokon_model(model_name, input_shape=(256, 256, 3), num_classes=10): 
    if model_name in model_dict: 
        return model_dict[model_name](input_shape=input_shape, num_classes=num_classes) 
    else: 
        raise ValueError(f"Model {model_name} not found in rokon!") 



import tensorflow as tf
from tensorflow.keras import layers, models

def RNet1(input_shape, num_classes, activation="relu"): 
    model = models.Sequential([ 
        layers.Conv2D(16, (3,3), activation=activation, input_shape=input_shape), 
        layers.MaxPooling2D(2,2), 
        layers.Conv2D(32, (3,3), activation=activation), 
        layers.MaxPooling2D(2,2), 
        layers.Flatten(), 
        layers.Dense(128, activation=activation), 
        layers.Dense(num_classes, activation='softmax')  # Output layer stays softmax
    ]) 
    return model 

def RNet2(input_shape, num_classes, activation="relu"): 
    model = models.Sequential([ 
        layers.Conv2D(32, (3,3), activation=activation, input_shape=input_shape), 
        layers.Conv2D(32, (3,3), activation=activation), 
        layers.MaxPooling2D(2,2), 
        layers.Conv2D(64, (3,3), activation=activation), 
        layers.MaxPooling2D(2,2), 
        layers.Flatten(), 
        layers.Dense(256, activation=activation), 
        layers.Dense(num_classes, activation='softmax')
    ]) 
    return model 

def RNet3(input_shape, num_classes, activation="relu"):
    model = models.Sequential([
        layers.Conv2D(16, (3,3), activation=activation, input_shape=input_shape),
        layers.MaxPooling2D(2,2),
        layers.Conv2D(16, (3,3), activation=activation),
        layers.MaxPooling2D(2,2),
        layers.Flatten(),
        layers.Dense(64, activation=activation),
        layers.Dense(num_classes, activation='softmax')
    ])
    return model

def RNet4(input_shape, num_classes, activation="relu"):
    model = models.Sequential([
        layers.Conv2D(32, (3,3), activation=activation, input_shape=input_shape),
        layers.Conv2D(32, (1,1), activation=activation),
        layers.MaxPooling2D(2,2),
        layers.Conv2D(64, (3,3), activation=activation),
        layers.Conv2D(64, (1,1), activation=activation),
        layers.MaxPooling2D(2,2),
        layers.Flatten(),
        layers.Dense(128, activation=activation),
        layers.Dense(num_classes, activation='softmax')
    ])
    return model

def RNet5(input_shape, num_classes, activation="relu"):
    model = models.Sequential([
        layers.DepthwiseConv2D((3, 3), activation=activation, input_shape=input_shape),
        layers.Conv2D(32, (1, 1), activation=activation),
        layers.MaxPooling2D(2, 2),
        layers.DepthwiseConv2D((3, 3), activation=activation),
        layers.Conv2D(64, (1, 1), activation=activation),
        layers.MaxPooling2D(2, 2),
        layers.Flatten(),
        layers.Dense(128, activation=activation),
        layers.Dense(num_classes, activation='softmax')
    ])
    return model

def RNet6(input_shape, num_classes, activation="relu"):
    model = models.Sequential([
        layers.DepthwiseConv2D((3, 3), activation=activation, input_shape=input_shape),
        layers.Conv2D(32, (1, 1), activation=activation),
        layers.MaxPooling2D(2, 2),
        layers.DepthwiseConv2D((3, 3), activation=activation),
        layers.Flatten(),
        layers.Dense(128, activation=activation),
        layers.Dense(num_classes, activation='softmax')
    ])
    return model

def RNet7(input_shape, num_classes, activation="relu"):
    model = models.Sequential([
        layers.Conv2D(64, (3, 3), activation=activation, input_shape=input_shape),
        layers.MaxPooling2D(2, 2),
        layers.Flatten(),
        layers.Dense(128, activation=activation),
        layers.Dense(num_classes, activation='softmax')
    ])
    return model

# Add this at the END of the file to allow wildcard imports
__all__ = ["RNet1", "RNet2", "RNet3", "RNet4", "RNet5", "RNet6", "RNet7"]



# Version 1.0
# from setuptools import setup, find_packages 
# setup(
# name="rokon", 
# version="1.0", 
# packages=find_packages(), 
# install_requires=[ 
# 'tensorflow', 
# ], 
# description="A lightweight CNN model repository", 
# author="rokayon", 
# author_email="rokayon.cse@gmail.com", 
# ) 

# Version 2.0
from setuptools import setup, find_packages
setup(
    name="rokon",  # Package name (this will be used in pip install)
    version="2.0.1",  # Update version as needed
    author="Rokonozzaman Ayon",
    author_email="rokayon.cse@gmail.com",
    description="A collection of  RNet (lightweight CNN) models",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/rokayon/rokon",  # Your GitHub repo
    packages=find_packages(),
    install_requires=[
        "tensorflow",  # Add required dependencies
        "numpy",
        "matplotlib",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)